@@ -76,7 +76,7 @@ class PhContextFacade(object):
             return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
         elif self.cmd == "publish":
             return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
-        elif self.cmd == "submit" | self.cmd == "status":
+        elif self.cmd == "submit":
             return self.path
         else:
             raise Exception("Something goes wrong!!!")
@@ -99,7 +99,7 @@ class PhContextFacade(object):
             elif self.cmd == "publish":
                 if not os.path.exists(self.dag_path):
                     raise exception_file_not_exist
-            elif self.cmd == "submit" | self.cmd == "status":
+            elif self.cmd == "submit":
                 phlogger.info("command submit or status, do nothing")
             else:
                 if not os.path.exists(self.path):
